@@ -6,7 +6,8 @@ require 'puppet/file_serving/mount'
 class Puppet::FileServing::Mount::Locales < Puppet::FileServing::Mount
   # Return an instance of the appropriate class.
   def find(relative_path, request)
-    return nil unless mod = request.environment.modules.find { |m|  m.locale(relative_path) }
+    mod = request.environment.modules.find { |m|  m.locale(relative_path) }
+    return nil unless mod
 
     path = mod.locale(relative_path)
 
@@ -16,13 +17,14 @@ class Puppet::FileServing::Mount::Locales < Puppet::FileServing::Mount
   def search(relative_path, request)
     # We currently only support one kind of search on locales - return
     # them all.
+    Puppet.debug("Warning: calling Locales.search with empty module path.") if request.environment.modules.empty?
     paths = request.environment.modules.find_all { |mod| mod.locales? }.collect { |mod| mod.locale_directory }
     if paths.empty?
       # If the modulepath is valid then we still need to return a valid root
       # directory for the search, but make sure nothing inside it is
       # returned.
       request.options[:recurse] = false
-      request.environment.modulepath.empty? ? [Puppet[:codedir]] : request.environment.modulepath
+      request.environment.modulepath.empty? ? nil : request.environment.modulepath
     else
       paths
     end
