@@ -7,12 +7,11 @@ class Puppet::Parser::AST
   AST = Puppet::Parser::AST
 
   include Puppet::Util::Errors
-  include Puppet::Util::MethodHelper
 
   attr_accessor :parent, :scope, :file, :line, :pos
 
   def inspect
-    "( #{self.class} #{self} #{@children.inspect} )"
+    "( #{self.class} #{self.to_s} #{@children.inspect} )"
   end
 
   # Evaluate the current object.  Just a stub method, since the subclass
@@ -44,14 +43,11 @@ class Puppet::Parser::AST
     end
   end
 
-  # Initialize the object.  Requires a hash as the argument, and
-  # takes each of the parameters of the hash and calls the setter
-  # method for them.  This is probably pretty inefficient and should
-  # likely be changed at some point.
-  def initialize(args)
-    set_options(args)
+  def initialize(file: nil, line: nil, pos: nil)
+    @file = file
+    @line = line
+    @pos = pos
   end
-
 end
 
 # And include all of the AST subclasses.
