@@ -9,6 +9,8 @@ require 'puppet/rest/routes'
 
 # The class that manages all aspects of our SSL certificates --
 # private keys, public keys, requests, etc.
+#
+# @deprecated Use {Puppet::SSL::SSLProvider} instead.
 class Puppet::SSL::Host
   # Yay, ruby's strange constant lookups.
   Key = Puppet::SSL::Key
@@ -121,7 +123,7 @@ class Puppet::SSL::Host
       generate_key unless key
 
       # get CA and optional CRL
-      sm = Puppet::SSL::StateMachine.new
+      sm = Puppet::SSL::StateMachine.new(onetime: true)
       sm.ensure_ca_certificates
 
       cert = get_host_certificate
@@ -179,10 +181,14 @@ ERROR_STRING
   # @return [Puppet::SSL::CertificateRequest, nil]
   def certificate_request
     unless @certificate_request
-      if csr = load_certificate_request_from_file
-        @certificate_request = csr
-      elsif csr = download_csr_from_ca
+      csr = load_certificate_request_from_file
+      if csr
         @certificate_request = csr
+      else
+        csr = download_csr_from_ca
+        if csr 
+          @certificate_request = csr
+        end
       end
     end
     @certificate_request
@@ -226,6 +232,7 @@ ERROR_STRING
     @key = @certificate = @certificate_request = nil
     @crl_usage = Puppet.settings[:certificate_revocation]
     @crl_path = Puppet.settings[:hostcrl]
+    Puppet.deprecation_warning(_("Puppet::SSL::Host is deprecated and will be removed in a future release of Puppet."));
   end
 
   # Extract the public key from the private key.
@@ -389,13 +396,17 @@ ERROR_STRING
   # no certificate could be found.
   # @return [Puppet::SSL::Certificate, nil]
   def get_host_certificate
-    if cert = check_for_certificate_on_disk(name)
-      return cert
-    elsif cert = download_certificate_from_ca(name)
-      save_host_certificate(cert)
+    cert = check_for_certificate_on_disk(name)
+    if cert
       return cert
     else
-      return nil
+      cert = download_certificate_from_ca(name)
+      if cert
+        save_host_certificate(cert)
+        return cert
+      else
+        return nil
+      end
     end
   end
 
