@@ -23,6 +23,9 @@ module Puppet
       consider developing a custom resource type instead, as it will be much
       more predictable and maintainable.
 
+      **Duplication:** Even though `command` is the namevar, Puppet allows
+      multiple `exec` resources with the same `command` value.
+
       **Refresh:** `exec` resources can respond to refresh events (via
       `notify`, `subscribe`, or the `~>` arrow). The refresh behavior of execs
       is non-standard, and can be affected by the `refresh` and
@@ -47,7 +50,7 @@ module Puppet
       it becomes doubly important to make sure the run conditions are restricted.
 
       **Autorequires:** If Puppet is managing an exec's cwd or the executable
-      file used in an exec's command, the exec resource will autorequire those
+      file used in an exec's command, the exec resource autorequires those
       files. If Puppet is managing the user that an exec should run as, the
       exec resource will autorequire that user."
 
@@ -138,7 +141,8 @@ module Puppet
           self.fail Puppet::Error, _("Command exceeded timeout"), $!
         end
 
-        if log = @resource[:logoutput]
+        log = @resource[:logoutput]
+        if log
           case log
           when :true
             log = @resource[:loglevel]
@@ -176,7 +180,10 @@ module Puppet
         succeeds, any output produced will be logged at the instance's
         normal log level (usually `notice`), but if the command fails
         (meaning its return code does not match the specified code) then
-        any output is logged at the `err` log level."
+        any output is logged at the `err` log level.
+
+        Multiple `exec` resources can use the same `command` value; Puppet
+        only uses the resource title to ensure `exec`s are unique."
 
       validate do |command|
         raise ArgumentError, _("Command must be a String, got value of class %{klass}") % { klass: command.class } unless command.is_a? String
@@ -429,7 +436,7 @@ module Puppet
         `grep` determines it's already there.
 
         Note that this test command runs with the same `provider`, `path`,
-        `user`, and `group` as the main command. If the `path` isn't set, you
+        `user`, `cwd`, and `group` as the main command. If the `path` isn't set, you
         must fully qualify the command's name.
 
         This parameter can also take an array of commands. For example:
@@ -481,7 +488,7 @@ module Puppet
         This would run `logrotate` only if that test returns true.
 
         Note that this test command runs with the same `provider`, `path`,
-        `user`, and `group` as the main command. If the `path` isn't set, you
+        `user`, `cwd`, and `group` as the main command. If the `path` isn't set, you
         must fully qualify the command's name.
 
         This parameter can also take an array of commands. For example:
@@ -542,7 +549,8 @@ module Puppet
       }
 
       [:onlyif, :unless].each { |param|
-        next unless tmp = self[param]
+        tmp = self[param]
+        next unless tmp
 
         tmp = [tmp] unless tmp.is_a? Array
 
@@ -564,7 +572,8 @@ module Puppet
 
     autorequire(:user) do
       # Autorequire users if they are specified by name
-      if user = self[:user] and user !~ /^\d+$/
+      user = self[:user]
+      if user && user !~ /^\d+$/
         user
       end
     end
@@ -610,7 +619,8 @@ module Puppet
     # Run the command, or optionally run a separately-specified command.
     def refresh
       if self.check_all_attributes(true)
-        if cmd = self[:refresh]
+        cmd = self[:refresh]
+        if cmd
           provider.run(cmd)
         else
           self.property(:returns).sync
@@ -628,7 +638,7 @@ module Puppet
       sensitive = false
       parameters_to_check = [:command, :unless, :onlyif]
 
-      parameters_to_check.each do |p| 
+      parameters_to_check.each do |p|
         if sensitive_parameters.include?(p)
           sensitive_parameters.delete(p)
           sensitive = true
