@@ -4,9 +4,11 @@
 
 module Puppet
   Type.newtype(:notify) do
-    @doc = "Sends an arbitrary message to the agent run-time log."
+    @doc = "Sends an arbitrary message to the agent run-time log. It's important to note that the notify resource type is not idempotent. As a result, notifications are shown as a change on every Puppet run."
 
-    newproperty(:message) do
+    apply_to_all
+
+    newproperty(:message, :idempotent => false) do
       desc "The message to be sent to the log."
       def sync
         case @resource["withpath"]
@@ -30,7 +32,7 @@ module Puppet
     end
 
     newparam(:withpath) do
-      desc "Whether to show the full object path. Defaults to false."
+      desc "Whether to show the full object path."
       defaultto :false
 
       newvalues(:true, :false)
