@@ -60,7 +60,7 @@ class Puppet::Util::Log
   end
 
   def self.close_all
-    destinations.keys.each { |dest|
+    @destinations.keys.each { |dest|
       close(dest)
     }
     #TRANSLATORS "Log.close_all" is a method name and should not be translated
@@ -125,7 +125,7 @@ class Puppet::Util::Log
       return
     end
 
-    name, type = @desttypes.find do |name, klass|
+    _, type = @desttypes.find do |name, klass|
       klass.match?(dest)
     end
 
@@ -147,7 +147,12 @@ class Puppet::Util::Log
       Puppet.log_exception(detail)
 
       # If this was our only destination, then add the console back in.
-      newdestination(:console) if @destinations.empty? and (dest != :console and dest != "console")
+      if destinations.empty? && dest.intern != :console
+        newdestination(:console)
+      end
+
+      # Re-raise (end exit Puppet) because we could not set up logging correctly.
+      raise detail
     end
   end
 
@@ -164,8 +169,6 @@ class Puppet::Util::Log
     end
   end
 
-  private
-  # produces UTF-8 strings or dumps strings when they cannot be re-encoded
   def Log.coerce_string(str)
     return Puppet::Util::CharacterEncoding.convert_to_utf_8(str) if str.valid_encoding?
 
@@ -175,8 +178,7 @@ class Puppet::Util::Log
     message += '\n' + _("Backtrace:\n%{backtrace}") % { backtrace: caller[0..10].join("\n") }
     message
   end
-
-  public
+  private_class_method :coerce_string
 
   # Route the actual message. FIXME There are lots of things this method
   # should do, like caching and a bit more.  It's worth noting that there's
@@ -298,13 +300,15 @@ class Puppet::Util::Log
 
     @time = Time.now
 
-    if tags = args[:tags]
+    tags = args[:tags]
+    if tags
       tags.each { |t| self.tag(t) }
     end
 
     # Don't add these unless defined (preserve 3.x API as much as possible)
     [:file, :line, :pos, :issue_code, :environment, :node, :backtrace].each do |attr|
-      next unless value = args[attr]
+      value = args[attr]
+      next unless value
       send(attr.to_s + '=', value)
     end
 
@@ -322,7 +326,8 @@ class Puppet::Util::Log
     end
     # Don't add these unless defined (preserve 3.x API as much as possible)
     %w(file line pos issue_code environment node backtrace).each do |name|
-      next unless value = data[name]
+      value = data[name]
+      next unless value
       send(name + '=', value)
     end
   end
@@ -381,7 +386,7 @@ class Puppet::Util::Log
   def source=(source)
     if defined?(Puppet::Type) && source.is_a?(Puppet::Type)
       @source = source.path
-      source.tags.each { |t| tag(t) }
+      merge_tags_from(source)
       self.file = source.file
       self.line = source.line
     else
