@@ -46,12 +46,11 @@ module Puppet::Util::Windows
 
       subkey_max_len, _ = reg_query_info_key_max_lengths(key)
 
-      loop do
+      begin
         subkey, filetime = reg_enum_key(key, index, subkey_max_len)
         yield subkey, filetime if !subkey.nil?
         index += 1
-        break if subkey.nil?
-      end
+      end while !subkey.nil?
 
       index
     end
@@ -94,12 +93,11 @@ module Puppet::Util::Windows
 
       _, value_max_len = reg_query_info_key_max_lengths(key)
 
-      loop do
+      begin
         subkey, type, data = reg_enum_value(key, index, value_max_len)
         yield subkey, type, data if !subkey.nil?
         index += 1
-        break if subkey.nil?
-      end
+      end while !subkey.nil?
 
       index
     end
@@ -316,7 +314,7 @@ module Puppet::Util::Windows
 
     def sanitize(value)
       # Replace null bytes with a space
-      value.tr!("\x00", ' ')
+      value.gsub!("\x00", ' ')
       value
     end
 
